@@ -173,7 +173,7 @@ let features =
       I "sys/types.h"; I "sys/stat.h";
       I "unistd.h"; I "stdio.h";
       D "S_IFREG";
-      S "fstatat"; S "openat"; S "unlinkat"; S "renameat"; S "mkdirat"; S "linkat"; S "symlinkat";
+      S "fstatat"; S "openat"; S "unlinkat"; S "renameat"; S "mkdirat"; S "linkat"; S "symlinkat"; S "readlinkat";
     ];
     "DIRFD", L[
       I "sys/types.h";
@@ -192,6 +192,13 @@ let features =
       S "ioctl";
       T "struct ifconf"; T "struct ifreq";
     ];
+    "IFADDRS", L[
+      I "sys/types.h";
+      I "ifaddrs.h";
+      S "getifaddrs";
+      S "freeifaddrs";
+      T "struct ifaddrs";
+    ];
     "INET_NTOA", L[
       I "sys/socket.h";
       I "netinet/in.h";
